********
Glossary
********

.. glossary::

    Base64
        A group of similar binary-to-text encoding schemes that represent binary
        data in an ASCII string format by translating it into a radix-64
        representation.

        .. seealso:: https://en.wikipedia.org/wiki/Base64

    Bash
        :term:`Unix Shell` first released in 1989. It is available as the
        default login shell for most Linux distribution and Apple macOS.
        A version is available on Windows 10.

        .. seealso:: https://en.wikipedia.org/wiki/C_shell

    C-Shell
        :term:`Unix Shell` created in the late 1970s. It is available on most
        Linux distributions and Apple macOS, though it is usually considered as
        `unfit for development
        <http://www.faqs.org/faqs/unix-faq/shell/csh-whynot/>`_.

        .. seealso:: https://en.wikipedia.org/wiki/C_shell

    JSON
        JavaScript Object Notation is a lightweight data-interchange format.

        .. seealso:: http://www.json.org/

    Mustache
        Simple web template system with implementations available for multiple
        languages

        .. seealso:: https://mustache.github.io

    PEP 440
        Version Identification and Dependency Specification for :term:`Python`.

        .. seealso:: https://www.python.org/dev/peps/pep-0440/

    Pip
        A recommended tool for installing :term:`Python` packages.

        .. seealso:: https://pip.pypa.io

    Python
        A programming language that lets you work quickly and integrate systems
        more effectively.

        .. seealso:: https://www.python.org/

    TOML
        TOML is a file format for configuration files.

        .. seealso:: https://en.wikipedia.org/wiki/TOML

    Unix Shell
        Command line interpreter providing a user interaction to use traditional
        Unix-like commands (such as `ls`, `cd`, `awk`, etc.) or execute scripts.

        .. seealso:: https://en.wikipedia.org/wiki/Unix_shell

    Virtualenv
        A tool to create isolated Python environments.

        .. seealso:: https://virtualenv.pypa.io/en/latest/
